==> linshare-core-1.6.1-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/entities/Internal.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.entities;

import java.util.UUID;

import org.linagora.linshare.core.domain.constants.AccountType;
import org.linagora.linshare.webservice.dto.UserDto;

/** Internal user.
 */
public class Internal extends User {

    /** Default constructor for hibernate. */
	public Internal() {
        super();
        lsUuid= UUID.randomUUID().toString();
    }

    /** Constructor.
     * @param firstName first name.
     * @param lastName last name.
     * @param mail email.
     * @param ldapUid 
     */
    public Internal(String firstName, String lastName, String mail, String ldapUid) {
        super(firstName, lastName, mail);
        this.ldapUid = ldapUid;
        this.lsUuid = UUID.randomUUID().toString();
    }

	public Internal(UserDto userDto) {
		super(userDto);
	}

	@Override
	public AccountType getAccountType() {
		return AccountType.INTERNAL;
	}
	
	@Override
	public String getAccountReprentation() {
		return this.firstName + " " + this.lastName + "(" + lsUuid + ", " + this.ldapUid + ")";
	}


}

==> linshare-core-1.7.8-src.tar.bz2: src/main/java/org/linagora/linshare/core/domain/entities/Internal.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.domain.entities;

import java.util.UUID;

import org.linagora.linshare.core.domain.constants.AccountType;
import org.linagora.linshare.webservice.dto.UserDto;

/**
 * Internal user.
 */
/**
 * @author fred
 *
 */
public class Internal extends User {

	/** Default constructor for hibernate. */
	public Internal() {
		super();
		lsUuid = UUID.randomUUID().toString();
	}

	/**
	 * Constructor.
	 * 
	 * @param firstName
	 *            first name.
	 * @param lastName
	 *            last name.
	 * @param mail
	 *            email.
	 * @param ldapUid
	 */
	public Internal(String firstName, String lastName, String mail,
			String ldapUid) {
		super(firstName, lastName, mail);
		this.ldapUid = ldapUid;
		this.lsUuid = UUID.randomUUID().toString();
	}

	public Internal(UserDto userDto) {
		super(userDto);
	}

	@Override
	public AccountType getAccountType() {
		return AccountType.INTERNAL;
	}

	@Override
	public String getAccountReprentation() {
		return this.firstName + " " + this.lastName + "(" + lsUuid + ", "
				+ this.ldapUid + ")";
	}
}
